/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2013 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task;

import java.net.URL;
import java.util.regex.Matcher;

import org.apache.tools.ant.types.LogLevel;
import org.ow2.petals.ant.AbstractInstallerAntTask;

/**
 * Ant task : jbi-deploy-service-assembly. 
 * <p>
 * This task deploys a service assembly into the JBI environment.
 * </p>
 * 
 * @author ddesjardins - EBM WebSourcing
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class DeployServiceAssemblyTask extends AbstractInstallerAntTask {

    /**
     * Creates a new instance of {@link DeployServiceAssemblyTask}
     * 
     */
    public DeployServiceAssemblyTask() {
        super();
    }

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.ant.AbstractJBIAntTask#doTask()
     */
    @Override
    public void doTask() throws Exception {
        URL fileURL = validateFileParameter();

        String serviceAssemblyReport = this.getJMXClient().getDeploymentServiceClient().deploy(
                fileURL);

        boolean isSUfailed = false;

        Matcher matcher = suResultpattern.matcher(serviceAssemblyReport);
        while (matcher.find()) {
            isSUfailed = true;
            log("Failed to deploy SU '" + matcher.group(1) + "':\n" + matcher.group(2),
                    LogLevel.WARN.getLevel());
        }

        matcher = saNamepattern.matcher(serviceAssemblyReport);
        if (matcher.find()) {
            if ("SUCCESS".equals(matcher.group(1).toUpperCase())) {
                if (isSUfailed) {
                    log("Service assembly '" + matcher.group(2)
                            + "' deployed with some SU deployment in failure", LogLevel.WARN
                            .getLevel());
                } else {
                    log("Service Assembly '" + matcher.group(2) + "' deployed");
                }

            } else {
                log("Failed to deploy Service Assembly '" + matcher.group(2) + "'", LogLevel.ERR
                        .getLevel());
            }
        }
    }
}
